@@ -2,7 +2,7 @@ __all__ = ["GoogleAPI", "Resource", "Method"]
 
 import re
 import warnings
-from urllib.parse import urlencode, quote_plus
+from urllib.parse import urlencode, quote
 from functools import wraps
 from typing import List, Generic, TypeVar
 
@@ -453,7 +453,7 @@ class Method:
 
         # Build full url minus query & fragment
         url = self._build_url(
-            base_url=base_url, uri_params=uri_params, validate=validate
+            base_url=base_url, uri_params=uri_params.copy(), validate=validate
         )
 
         # Filter out query parameters from all uri_params that were passed to this method
@@ -472,22 +472,37 @@ class Method:
         if validate is True:
             if passed_query_params:
                 for param_name, passed_param in passed_query_params.items():
-                    self._validate(
-                        passed_param,
-                        self.parameters[param_name],
-                        schema_name=param_name,
-                    )
+                    schema = self.parameters[param_name]
+                    if schema.get('repeated') and isinstance(passed_param, (list, set, tuple)):
+                        for param in passed_param:
+                            self._validate(
+                                param,
+                                schema,
+                                schema_name=param_name
+                            )
+                    else:
+                        self._validate(
+                            passed_param,
+                            schema,
+                            schema_name=param_name,
+                        )
 
         # Join query params
         if passed_query_params:
-            uri = url + "?" + urlencode(passed_query_params)
+            uri = url + "?" + urlencode(passed_query_params, True)
         else:
             uri = url
 
-        # Pop uri_params consumed
+        # Pop query uri_params consumed
         for param_name, _ in passed_query_params.items():
             del uri_params[param_name]
 
+        # Pop uri_params consumed
+        # for param_name in self["parameterOrder"]:
+        for param_name in self.path_parameters:
+            if param_name in uri_params:
+                del uri_params[param_name]
+
         # Warn if not all uri_params were consumed/popped
         if uri_params:  # should be empty by now
             # If there's room for addtionalProperties, validate and add them to the URI
@@ -581,7 +596,7 @@ class Method:
                 self._validate_url(sorted_required_path_params)
 
             for k, v in sorted_required_path_params.items():
-                sorted_required_path_params[k] = quote_plus(str(v))
+                sorted_required_path_params[k] = quote(str(v))
 
             # Build full path
             # replace named placeholders with empty ones. e.g. {param} --> {}
